summaryrefslogtreecommitdiffstats
path: root/src/packet_cb.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/packet_cb.c')
-rw-r--r--src/packet_cb.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/packet_cb.c b/src/packet_cb.c
index cd869aa7..472e8a73 100644
--- a/src/packet_cb.c
+++ b/src/packet_cb.c
@@ -154,20 +154,20 @@ SSH_PACKET_CALLBACK(ssh_packet_newkeys){
} else {
ssh_key key;
/* client */
- rc = make_sessionid(session);
+ rc = ssh_make_sessionid(session);
if (rc != SSH_OK) {
goto error;
}
/*
* Set the cryptographic functions for the next crypto
* (it is needed for generate_session_keys for key lengths)
*/
if (crypt_set_algorithms(session, SSH_3DES) /* knows nothing about DES*/ ) {
goto error;
}
- if (generate_session_keys(session) < 0) {
+ if (ssh_generate_session_keys(session) < 0) {
goto error;
}
@@ -154,20 +154,20 @@ SSH_PACKET_CALLBACK(ssh_packet_newkeys){
/*
* Set the cryptographic functions for the next crypto
- * (it is needed for generate_session_keys for key lengths)
+ * (it is needed for ssh_generate_session_keys for key lengths)
*/
if (crypt_set_algorithms(session, SSH_3DES) /* knows nothing about DES*/ ) {